from _typeshed import Incomplete
from typing import Any

algorithms_table: Any
salted_table: Any

def hashed(algorithm, value, salt: Incomplete | None = ..., raw: bool = ..., encoding: str = ...): ...
